pub struct Property {
pub tag: TagNameType,
pub args: Box<[Expr]>,
}Fields
tag: TagNameTypeSP or type.SP. The type of single SP is unkown until queried from definition.
args: Box<[Expr]>Args in SP(args) such as arg1, arg2.
Implementations
Sourceimpl Property
impl Property
Sourcepub fn gen_doc(&self) -> Option<String>
pub fn gen_doc(&self) -> Option<String>
Generate #[doc] for this property from its desc string interpolation.
None means SP is not defined with desc, thus nothing to generate.
Sourcepub fn args_in_any_tag(&self) -> Option<Vec<PropertiesAndReason>>
pub fn args_in_any_tag(&self) -> Option<Vec<PropertiesAndReason>>
SPs in any tag. None means the tag is not any or empty args.